%% FACS data analysis: scatter plots and histograms for YFP expression in liposomes.
% This program analyses FACS data for creating scatter plots and
% histograms.
% Steps for importing data:
    % Take the .fcs data from FACS instrument.
    % Import .fcs data into https://community.cytobank.org/
    % Filter the data accordingly (NO debris TX-red + NO debris dsGreen/YFP)
    % Export the filtered .fcs data as .txt files from https://community.cytobank.org/
        % Go to actions/export/export events/.txt file format/chose filter population to export/chose files to export/leave the channels as it is (all channels will be exported 
    % Save the .txt data in the same folder as this script is (the folder should also have importfile.m)

table{1}= importfile('Duplicate _1 _Ana sorting_Water.fcs_file_internal_comp_Ungated.txt'); 
table{2}= importfile('Duplicate _1 _Ana sorting_1nM oriYFP.fcs_file_internal_comp_Ungated.txt'); 
table{3}= importfile('Duplicate _1 _Ana sorting_10pM mix EB (110).fcs_file_internal_comp_Ungated.txt'); 
table{4}= importfile('Duplicate _1 _Ana sorting_10pM mix RB (110) with purified proteins.fcs_file_internal_comp_Ungated.txt'); 
table{5}= importfile('Duplicate _1 _Ana sorting_10pM 110 RB with purified proteins (duplicate).fcs_file_internal_comp_Ungated.txt'); 
table{6}= importfile('Duplicate _1 _Ana sorting_110 mix RB with G340.fcs_file_internal_comp_Ungated.txt'); 

samples = ["water", "EB 1 nM YFP", "EB mix YFP:MinD", "purCADGE YFP:MinD", "purCADGE YFP:MinD", "expCADGE YFP:MinD"]

set(groot,{'DefaultAxesXColor','DefaultAxesYColor','DefaultAxesZColor','DefaultAxesLineWidth'},{'k','k','k',1})

% defining the water threshold
%treshold=mean((table{6}.GFPA)+(6*std(table{6}.GFPA)))

YFP2=[];

for c = 1:6;
    YFP = [] %Expressed population (change the table{#} depending on the population to analyze)
for i = 1:length(table{c}.GFPA)
    if table{c}.GFPA(i) > 54*(table{c}.TexasRedA(i)^0.33) 
        %&& table{c}.TexasRedA(i) > mean((table{1}.TexasRedA)+(2*std(table{1}.TexasRedA)))
        YFP = [YFP; table{c}.GFPA(i)];
    end
end

Per_YFP = (length(YFP)/length(table{c}.GFPA))*100; %percentage of YFP expressing liposomes.
Per_YFP = round(Per_YFP,2) %round the percentage to only 2 decimals 
str = '' + string(Per_YFP) + {'%'} %conver to string for it to appear in the scatter plot.

%Scatter plots from FACS
f(c) = figure;
box on
set(gca,'FontSize',14);
h = get(gca, 'title');
set(h, 'FontSize',14)

scatter(table{c}.TexasRedA, table{c}.GFPA,7,'filled','MarkerFaceColor','#77AC30')
hold on
plot(10^1:10^6,54.*(10^1:10^6).^0.33,'--k','LineWidth',1.5)
set(gca,'xscale','log')
set(gca,'yscale','log')

xlim([10^1 10^6])
ylim([10^1 10^6])
legend(samples(c),'background treshold','Location','NW','FontSize',12)
legend boxoff
xlabel('Membrane Dye Intensity')
ylabel('eYFP Intensity')
set(gca,'FontSize',14);
h = get(gca, 'title');
set(h, 'FontSize',14)
print(f(c),'-dpng','-r1000','PF1 flow cytometry')

YFP_cell{c}=YFP;
Per_YFP_cell{c}=Per_YFP

end

% f3 = figure; 
% histogram(YFP_cell{1},'BinWidth',100,'facecolor','#FF0000','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% hold on
% histogram(YFP_cell{3},'BinWidth',100,'facecolor','#0000FF','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% histogram(YFP_cell{5},'BinWidth',100,'facecolor','#00FFFF','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% xline(mean((table{6}.GFPA)+(4*std(table{6}.GFPA))),'--k','LineWidth',2,'fontsize',20)
% set(gca,'yscale','log')
% xlim([-500 11e3])
% legend('oriYFP "all expresed','oriYFP "all purified"','oriYFP only','Water Background Treshold','Location','NE','FontSize',12)
% legend boxoff
% xlabel('YFP intensity ','FontSize',14);
% ylabel('Log(count)','FontSize',14);
% set(gca,'fontsize',14)
% print(f3,'-dpng','-r1000','PF3 Histogram')
